import { GraphQLResolveInfo, GraphQLScalarType, GraphQLScalarTypeConfig } from 'graphql';
import * as ApolloReactCommon from '@apollo/react-common';
export declare type Maybe<T> = T | null;
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    AnyObject: any;
    JSON: any;
    JSONObject: any;
};
export declare type ClientCounter = {
    __typename?: 'ClientCounter';
    counter?: Maybe<Scalars['Int']>;
};
/**  Database counter  */
export declare type Counter = {
    __typename?: 'Counter';
    /**  Current amount  */
    amount: Scalars['Int'];
};
export declare type FieldError = {
    __typename?: 'FieldError';
    field: Scalars['String'];
    message: Scalars['String'];
};
export declare type HealthCheckRequest = {
    host?: Maybe<Scalars['String']>;
    topic?: Maybe<Scalars['String']>;
    type: HealthCheckType;
};
export declare enum HealthCheckType {
    Nats = "Nats",
    Redis = "Redis",
    Mongo = "Mongo",
    Custom = "Custom"
}
export declare type Mutation = {
    __typename?: 'Mutation';
    dummy?: Maybe<Scalars['Int']>;
    /**  Increase counter value returns current counter amount  */
    addCounter?: Maybe<Counter>;
    /**  sync cached counter with current value  */
    syncCachedCounter?: Maybe<Scalars['Boolean']>;
    /**  add Counter  */
    addMoleculerCounter?: Maybe<Counter>;
    addCounterState?: Maybe<ClientCounter>;
};
export declare type MutationAddCounterArgs = {
    amount?: Maybe<Scalars['Int']>;
};
export declare type MutationAddMoleculerCounterArgs = {
    amount?: Maybe<Scalars['Int']>;
};
export declare type MutationAddCounterStateArgs = {
    amount: Scalars['Int'];
};
export declare type Node = {
    id: Scalars['ID'];
};
export declare type Query = {
    __typename?: 'Query';
    dummy?: Maybe<Scalars['Int']>;
    /**  Counter  */
    counter?: Maybe<Counter>;
    /**  Counter from Datasource  */
    counterCache?: Maybe<Counter>;
    /**  Moleculer Counter  */
    moleculerCounter?: Maybe<Counter>;
    health?: Maybe<Scalars['Boolean']>;
    counterState?: Maybe<ClientCounter>;
};
export declare type QueryHealthArgs = {
    request: HealthCheckRequest;
};
export declare type Subscription = {
    __typename?: 'Subscription';
    dummy?: Maybe<Scalars['Int']>;
    /**  Subscription fired when anyone increases counter  */
    counterUpdated?: Maybe<Counter>;
    moleculerCounterUpdate?: Maybe<Counter>;
};
export declare type AddCounterStateMutationVariables = {
    amount: Scalars['Int'];
};
export declare type AddCounterStateMutation = ({
    __typename?: 'Mutation';
} & {
    addCounterState: Maybe<({
        __typename?: 'ClientCounter';
    } & Pick<ClientCounter, 'counter'>)>;
});
export declare type AddCounterMutationVariables = {
    amount: Scalars['Int'];
};
export declare type AddCounterMutation = ({
    __typename?: 'Mutation';
} & {
    addCounter: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type AddCounter_WsMutationVariables = {
    amount: Scalars['Int'];
};
export declare type AddCounter_WsMutation = ({
    __typename?: 'Mutation';
} & {
    addCounter: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type SyncCachedCounterMutationVariables = {};
export declare type SyncCachedCounterMutation = ({
    __typename?: 'Mutation';
} & Pick<Mutation, 'syncCachedCounter'>);
export declare type CounterCacheQueryQueryVariables = {};
export declare type CounterCacheQueryQuery = ({
    __typename?: 'Query';
} & {
    counterCache: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type CounterStateQueryVariables = {};
export declare type CounterStateQuery = ({
    __typename?: 'Query';
} & {
    counterState: Maybe<({
        __typename?: 'ClientCounter';
    } & Pick<ClientCounter, 'counter'>)>;
});
export declare type CounterQueryQueryVariables = {};
export declare type CounterQueryQuery = ({
    __typename?: 'Query';
} & {
    counter: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type OnCounterUpdatedSubscriptionVariables = {};
export declare type OnCounterUpdatedSubscription = ({
    __typename?: 'Subscription';
} & {
    counterUpdated: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type ResolversTypes = {
    Query: ResolverTypeWrapper<{}>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    Counter: ResolverTypeWrapper<Counter>;
    HealthCheckRequest: HealthCheckRequest;
    String: ResolverTypeWrapper<Scalars['String']>;
    HealthCheckType: HealthCheckType;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
    ClientCounter: ResolverTypeWrapper<ClientCounter>;
    Mutation: ResolverTypeWrapper<{}>;
    Subscription: ResolverTypeWrapper<{}>;
    AnyObject: ResolverTypeWrapper<Scalars['AnyObject']>;
    JSON: ResolverTypeWrapper<Scalars['JSON']>;
    JSONObject: ResolverTypeWrapper<Scalars['JSONObject']>;
    FieldError: ResolverTypeWrapper<FieldError>;
    Node: ResolverTypeWrapper<Node>;
    ID: ResolverTypeWrapper<Scalars['ID']>;
};
/** Mapping between all available schema types and the resolvers parents */
export declare type ResolversParentTypes = {
    Query: {};
    Int: Scalars['Int'];
    Counter: Counter;
    HealthCheckRequest: HealthCheckRequest;
    String: Scalars['String'];
    HealthCheckType: HealthCheckType;
    Boolean: Scalars['Boolean'];
    ClientCounter: ClientCounter;
    Mutation: {};
    Subscription: {};
    AnyObject: Scalars['AnyObject'];
    JSON: Scalars['JSON'];
    JSONObject: Scalars['JSONObject'];
    FieldError: FieldError;
    Node: Node;
    ID: Scalars['ID'];
};
export interface AnyObjectScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['AnyObject'], any> {
    name: 'AnyObject';
}
export declare type ClientCounterResolvers<ContextType = any, ParentType extends ResolversParentTypes['ClientCounter'] = ResolversParentTypes['ClientCounter']> = {
    counter?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
};
export declare type CounterResolvers<ContextType = any, ParentType extends ResolversParentTypes['Counter'] = ResolversParentTypes['Counter']> = {
    amount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
};
export declare type FieldErrorResolvers<ContextType = any, ParentType extends ResolversParentTypes['FieldError'] = ResolversParentTypes['FieldError']> = {
    field?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    message?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
};
export interface JsonScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['JSON'], any> {
    name: 'JSON';
}
export interface JsonObjectScalarConfig extends GraphQLScalarTypeConfig<ResolversTypes['JSONObject'], any> {
    name: 'JSONObject';
}
export declare type MutationResolvers<ContextType = any, ParentType extends ResolversParentTypes['Mutation'] = ResolversParentTypes['Mutation']> = {
    dummy?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    addCounter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType, MutationAddCounterArgs>;
    syncCachedCounter?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
    addMoleculerCounter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType, MutationAddMoleculerCounterArgs>;
    addCounterState?: Resolver<Maybe<ResolversTypes['ClientCounter']>, ParentType, ContextType, RequireFields<MutationAddCounterStateArgs, 'amount'>>;
};
export declare type NodeResolvers<ContextType = any, ParentType extends ResolversParentTypes['Node'] = ResolversParentTypes['Node']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    id?: Resolver<ResolversTypes['ID'], ParentType, ContextType>;
};
export declare type QueryResolvers<ContextType = any, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = {
    dummy?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    counter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType>;
    counterCache?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType>;
    moleculerCounter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType>;
    health?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<QueryHealthArgs, 'request'>>;
    counterState?: Resolver<Maybe<ResolversTypes['ClientCounter']>, ParentType, ContextType>;
};
export declare type SubscriptionResolvers<ContextType = any, ParentType extends ResolversParentTypes['Subscription'] = ResolversParentTypes['Subscription']> = {
    dummy?: SubscriptionResolver<Maybe<ResolversTypes['Int']>, "dummy", ParentType, ContextType>;
    counterUpdated?: SubscriptionResolver<Maybe<ResolversTypes['Counter']>, "counterUpdated", ParentType, ContextType>;
    moleculerCounterUpdate?: SubscriptionResolver<Maybe<ResolversTypes['Counter']>, "moleculerCounterUpdate", ParentType, ContextType>;
};
export declare type Resolvers<ContextType = any> = {
    AnyObject?: GraphQLScalarType;
    ClientCounter?: ClientCounterResolvers<ContextType>;
    Counter?: CounterResolvers<ContextType>;
    FieldError?: FieldErrorResolvers<ContextType>;
    JSON?: GraphQLScalarType;
    JSONObject?: GraphQLScalarType;
    Mutation?: MutationResolvers<ContextType>;
    Node?: NodeResolvers;
    Query?: QueryResolvers<ContextType>;
    Subscription?: SubscriptionResolvers<ContextType>;
};
/**
 * @deprecated
 * Use "Resolvers" root object instead. If you wish to get "IResolvers", add "typesPrefix: I" to your config.
*/
export declare type IResolvers<ContextType = any> = Resolvers<ContextType>;
export declare const AddCounterStateDocument: import("graphql").DocumentNode;
export declare type AddCounterStateMutationResult = ApolloReactCommon.MutationResult<AddCounterStateMutation>;
export declare type AddCounterStateMutationOptions = ApolloReactCommon.BaseMutationOptions<AddCounterStateMutation, AddCounterStateMutationVariables>;
export declare const AddCounterDocument: import("graphql").DocumentNode;
export declare type AddCounterMutationResult = ApolloReactCommon.MutationResult<AddCounterMutation>;
export declare type AddCounterMutationOptions = ApolloReactCommon.BaseMutationOptions<AddCounterMutation, AddCounterMutationVariables>;
export declare const AddCounter_WsDocument: import("graphql").DocumentNode;
export declare type AddCounter_WsMutationResult = ApolloReactCommon.MutationResult<AddCounter_WsMutation>;
export declare type AddCounter_WsMutationOptions = ApolloReactCommon.BaseMutationOptions<AddCounter_WsMutation, AddCounter_WsMutationVariables>;
export declare const SyncCachedCounterDocument: import("graphql").DocumentNode;
export declare type SyncCachedCounterMutationResult = ApolloReactCommon.MutationResult<SyncCachedCounterMutation>;
export declare type SyncCachedCounterMutationOptions = ApolloReactCommon.BaseMutationOptions<SyncCachedCounterMutation, SyncCachedCounterMutationVariables>;
export declare const CounterCacheQueryDocument: import("graphql").DocumentNode;
export declare type CounterCacheQueryQueryResult = ApolloReactCommon.QueryResult<CounterCacheQueryQuery, CounterCacheQueryQueryVariables>;
export declare const CounterStateDocument: import("graphql").DocumentNode;
export declare type CounterStateQueryResult = ApolloReactCommon.QueryResult<CounterStateQuery, CounterStateQueryVariables>;
export declare const CounterQueryDocument: import("graphql").DocumentNode;
export declare type CounterQueryQueryResult = ApolloReactCommon.QueryResult<CounterQueryQuery, CounterQueryQueryVariables>;
export declare const OnCounterUpdatedDocument: import("graphql").DocumentNode;
export declare type OnCounterUpdatedSubscriptionResult = ApolloReactCommon.SubscriptionResult<OnCounterUpdatedSubscription>;
